<?php
/**
 * 
 * Plugin Name: Easy Gallery Slider
 * Description: Responsive slider uses the images attached to a post or page. Simple to customize and configure.
 * Author: Daniel Berkman
 * Version: 0.6
 */

/**
 * Protection 
 * 
 * This string of code will prevent hacks from accessing the file directly.
 */
defined('ABSPATH') or die("Cannot access pages directly.");

add_action( 'wp_head', 'easygalleryslider_mainquerytest', 0 );
function easygalleryslider_mainquerytest() {
	global $easygalleryslider_mainquerytest, $post;
	$easygalleryslider_mainquerytest = null;
	$egs = get_option('easygalleryslider');
	switch($egs[auto_insert]) {
		case "0": $egs[auto_insert] = false; break;
		case "1": $egs[auto_insert] = is_single(); break;
		case "2": $egs[auto_insert] = is_page(); break;
		case "3": $egs[auto_insert] = is_singular(); break;
	}
	if($egs[auto_insert]) { 
			$easygalleryslider_mainquerytest = $post->ID;
			add_filter('the_content','easygalleryslider_insert_hook');
			add_action('wp_enqueue_scripts', 'easygalleryslider_enqueue');
	}
	elseif ($egs[shortcode] == true) {
		add_action('wp_enqueue_scripts', 'easygalleryslider_enqueue');
		add_shortcode( 'egslider', 'egs_shortcode' );
	}
}

function easygalleryslider_insert_hook($content) {
	global $easygalleryslider_mainquerytest;
	if ($easygalleryslider_mainquerytest == get_the_id()) {
		$content = easygalleryslider_insert().$content;
		$easygalleryslider_mainquerytest = null;
	}
	return $content;
}



function easygalleryslider_insert() {
	$content = '';
	$egs = get_option('easygalleryslider');
	$args = array(	'post_parent' => get_the_id(),
					'post_type' => 'attachment',
					'order'=> 'ASC',
					'orderby'=> 'menu_order',
					'numberposts' => -1,
					'post_mime_type' => 'image' );
	if ($egs[exclude] == true) { 
		add_filter( 'posts_where', 'easygalleryslider_where_filter', 10);
		$args[suppress_filters] = FALSE;
	}
	$images = get_children($args);
	if(count($images) > 0) { 
		$content = '<div class="flexslider"><ul class="slides">';
		foreach ($images as $image) {
			if($img = wp_get_attachment_image_src($image->ID,'full')) {
				if($egs[enlarge] <> true) $width = $img[1] < $egs[width]? $img[1] : $egs[width];
				else $width = $egs[width];
				$content .= '<li><img src="'.WP_PLUGIN_URL .'/easy-gallery-slider/timthumb.php?src='.urlencode($img[0]).'&w='.$width.'&h='.$egs[height].'&a=c" />';
				if($egs[title] == true) $content .= '<p class="flex-caption">'.get_the_title($image->ID).'</p>';
				$content .= '</li>';
			}
		}
		$content .= '</ul></div>
					<script type="text/javascript" charset="utf-8">
  					jQuery(window).load(function() {
  				  	jQuery(".flexslider").flexslider({';
		$fsoptions = $egs[fs];
		foreach($fsoptions as $key => $value) {
			if ($value === true) $value = "true";
			elseif ($value === false) $value = "false";
			elseif (is_numeric($value)) $value = (int) $value;
			else $value = "'$value'";
			$content .= "\n".$key.": ".$value.",";
		}
			$content.= '});
						}); </script>';
		}
		return $content;
}

function easygalleryslider_where_filter($where) {
	remove_filter( 'posts_where', 'easygalleryslider_where_filter', 10);
	$where .= " AND menu_order < 999";
	return $where;
}

// Enqueue stuff
function easygalleryslider_enqueue() {
	if (!is_admin()) {
		$isStyleUrl = plugins_url('flexslider.css', __FILE__);
		$isStyleFile = WP_PLUGIN_DIR . '/easy-gallery-slider/flexslider.css';
		if ( file_exists($isStyleFile) ) {
			wp_register_style('flexslider-Style', $isStyleUrl);
			wp_enqueue_style( 'flexslider-Style');
		}
		$isStyleUrl = plugins_url('easygalleryslider.css', __FILE__);
		$isStyleFile = WP_PLUGIN_DIR . '/easy-gallery-slider/easygalleryslider.css';
		if ( file_exists($isStyleFile) ) {	
			wp_register_style('easygalleryslider', $isStyleUrl);
			wp_enqueue_style( 'easygalleryslider');
		}
	wp_enqueue_script('flexslider', WP_PLUGIN_URL .'/easy-gallery-slider/jquery.flexslider.js', array('jquery'));
	}
}

// Admin Options Page
add_action('admin_init', 'easygalleryslider_admin_init');
function easygalleryslider_admin_init(){
	register_setting( 'easygalleryslider_options', 'easygalleryslider', 'easygalleryslider_options_validate' );
	add_settings_section('easygalleryslider_options', 'Main Settings', 'easygalleryslider_section_text', 'easygalleryslider');
	add_settings_field('auto_insert', 'Automatically insert above', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_options', array('field' => 'auto_insert'));
	add_settings_field('width', 'Max Width', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_options', array('field' => 'width'));
	add_settings_field('height', 'Height', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_options', array('field' => 'height'));
	add_settings_field('shortcode', 'Enable shortcode', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_options', array('field' => 'shortcode'));
	add_settings_field('exclude', 'Exclude images with menu order higher than 999', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_options', array('field' => 'exclude'));
	add_settings_section('easygalleryslider_flexslider_options', 'Style & Navigation Options', 'easygalleryslider_section_text', 'easygalleryslider');
	add_settings_field('enlarge', 'Enlarge small images past 100%', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'enlarge'));
	add_settings_field('fs_animation', 'Animation Style', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_animation'));
	add_settings_field('fs_slide_direction', 'Slide Direction', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_slide_direction'));
	add_settings_field('fs_slideshow', 'Automatically Slide', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_slideshow'));
	add_settings_field('fs_speed', 'Slideshow Speed', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_speed'));
	add_settings_field('fs_duration', 'Animation Duration', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_duration'));
	add_settings_field('fs_directionnav', 'Show prev/next buttons', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_directionnav'));
	add_settings_field('fs_controlnav', 'Show navigation "dots"', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_controlnav'));
	add_settings_field('fs_keynav', 'Keyboard navigation', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_keynav'));
	add_settings_field('fs_mousewheel', 'Mouse scroll wheel navigation', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_mousewheel'));
	add_settings_field('fs_pause', 'Show pause/play button', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_pause'));
	add_settings_field('fs_random', 'Randomize slides', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_random'));
	add_settings_field('fs_loop', 'Loop animation', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_loop'));
	add_settings_field('fs_actionpause', 'Pause when buttons clicked', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_actionpause'));
	add_settings_field('fs_hover', 'Pause slideshow when hovering', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'fs_hover'));
	add_settings_field('title', 'Show titles', 'easygalleryslider_field_text', 'easygalleryslider', 'easygalleryslider_flexslider_options', array('field' => 'title'));
}
function easygalleryslider_section_text() { echo ''; }
add_action('admin_menu', 'easygalleryslider_admin_add_page');
function easygalleryslider_admin_add_page() {
	add_options_page('Easy Gallery Slider', 'Easy Gallery Slider', 'manage_options', 'easygalleryslider', 'easygalleryslider_options_page');
}
function easygalleryslider_field_text($args) {
	$egsoptions = get_option('easygalleryslider');
	switch($args['field']) {
		case "fs_animation":
			echo '<select name="easygalleryslider[fs][animation]"><option value="fade"'.(($egsoptions[fs][animation]=='fade')?' selected="selected"':"").'>fade</option><option value="slide"'.(($egsoptions[fs][animation]=='slide')?' selected="selected"':"").'>slide</option></select>'; break;
		case "fs_slide_direction":
			echo '<select name="easygalleryslider[fs][slideDirection]"><option value="horizontal"'.(($egsoptions[fs][slideDirection]=='horizontal')?' selected="selected"':"").'>horizontal</option><option value="vertical"'.(($egsoptions[fs][slideDirection]=='vertical')?' selected="selected"':"").'>vertical</option></select>'; break;
		case "fs_slideshow":
			echo '<input type="checkbox" name="easygalleryslider[fs][slideshow]" value="true"'.(($egsoptions[fs][slideshow]==true)?' checked="checked"':"").' />'; break;
		case "fs_speed":
			echo '<input type="text" name="easygalleryslider[fs][slideshowSpeed]" size="3" value="'.$egsoptions[fs][slideshowSpeed].'" /> ms'; break;
		case "fs_duration":
			echo '<input type="text" name="easygalleryslider[fs][animationDuration]" size="3" value="'.$egsoptions[fs][animationDuration].'" /> ms'; break;
		case "fs_directionnav":
			echo '<input type="checkbox" name="easygalleryslider[fs][directionNav]" value="true"'.(($egsoptions[fs][directionNav]==true)?' checked="checked"':"").' />'; break;
		case "fs_controlnav":
			echo '<input type="checkbox" name="easygalleryslider[fs][controlNav]" value="true"'.(($egsoptions[fs][controlNav]==true)?' checked="checked"':"").' />'; break;
		case "fs_keynav":
			echo '<input type="checkbox" name="easygalleryslider[fs][keyboardNav]" value="true"'.(($egsoptions[fs][keyboardNav]==true)?' checked="checked"':"").' />'; break;
		case "fs_mousewheel":
			echo '<input type="checkbox" name="easygalleryslider[fs][mousewheel]" value="true"'.(($egsoptions[fs][mousewheel]==true)?' checked="checked"':"").' />'; break;
		case "fs_pause":
			echo '<input type="checkbox" name="easygalleryslider[fs][pausePlay]" value="true"'.(($egsoptions[fs][pausePlay]==true)?' checked="checked"':"").' />'; break;
		case "fs_random":
			echo '<input type="checkbox" name="easygalleryslider[fs][randomize]" value="true"'.(($egsoptions[fs][randomize]==true)?' checked="checked"':"").' />'; break;
		case "fs_loop":
			echo '<input type="checkbox" name="easygalleryslider[fs][animationLoop]" value="true"'.(($egsoptions[fs][animationLoop]==true)?' checked="checked"':"").' />'; break;
		case "fs_actionpause":
			echo '<input type="checkbox" name="easygalleryslider[fs][pauseOnAction]" value="true"'.(($egsoptions[fs][pauseOnAction]==true)?' checked="checked"':"").' />'; break;
		case "fs_hover":
			echo '<input type="checkbox" name="easygalleryslider[fs][pauseOnHover]" value="true"'.(($egsoptions[fs][pauseOnHover]==true)?' checked="checked"':"").' />'; break;
		case "width":
			echo '<input type="text" name="easygalleryslider[width]" size="3" value="'.$egsoptions[width].'" /> px'; break;
		case "height":
			echo '<input type="text" name="easygalleryslider[height]" size="3" value="'.$egsoptions[height].'" /> px'; break;
		case "enlarge":
			echo '<input type="checkbox" name="easygalleryslider[enlarge]" value="true"'.(($egsoptions[enlarge]==true)?' checked="checked"':"").' />'; break;
		case "auto_insert":
			echo '<select name="easygalleryslider[auto_insert]"><option value="0"'.(($egsoptions[auto_insert]===0)?' selected="selected"':"").'>none</option><option value="1"'.(($egsoptions[auto_insert]===1)?' selected="selected"':"").'>posts</option><option value="2"'.(($egsoptions[auto_insert]===2)?' selected="selected"':"").'>pages</option><option value="3"'.(($egsoptions[auto_insert]===3)?' selected="selected"':"").'>pages & post</option></select>'; break;
		case "title":
			echo '<input type="checkbox" name="easygalleryslider[title]" value="true"'.(($egsoptions[title]==true)?' checked="checked"':"").' />'; break;
		case "shortcode":
			echo '<input type="checkbox" name="easygalleryslider[shortcode]" value="true"'.(($egsoptions[shortcode]==true)?' checked="checked"':"").' /><br /><em>Scripts will load on every page.</em>'; break;
		case "exclude":
			echo '<input type="checkbox" name="easygalleryslider[exclude]" value="true"'.(($egsoptions[exclude]==true)?' checked="checked"':"").' /><br /><em>The menu order field is on the Gallery attachment tab of the individual posts.</em>'; break;
	}
}
function easygalleryslider_options_validate($input) { 
	$egs = get_option('easygalleryslider');
	$output[fs][animation] = $input[fs][animation]==('fade'||'slide')? $input[fs][animation] : $egs[fs][animation];
	$output[fs][slideDirection] = $input[fs][slideDirection]==('horizontal'||'vertical')? $input[fs][slideDirection] : $egs[fs][slideDirection];
	$output[fs][slideshow] = $input[fs][slideshow]=='true'? true : false;
	$output[fs][slideshowSpeed] = is_numeric($input[fs][slideshowSpeed])? (int)$input[fs][slideshowSpeed] : $egs[fs][slideshowSpeed];
	$output[fs][animationDuration] = is_numeric($input[fs][animationDuration])? (int)$input[fs][animationDuration] : $egs[fs][animationDuration];
	$output[fs][directionNav] = $input[fs][directionNav]=='true'? true : false;
	$output[fs][controlNav] = $input[fs][controlNav]=='true'? true : false;
	$output[fs][keyboardNav] = $input[fs][keyboardNav]=='true'? true : false;
	$output[fs][mousewheel] = $input[fs][mousewheel]=='true'? true : false;
	$output[fs][pausePlay] = $input[fs][pausePlay]=='true'? true : false;
	$output[fs][randomize] = $input[fs][randomize]=='true'? true : false;
	$output[fs][animationLoop] = $input[fs][animationLoop]=='true'? true : false;
	$output[fs][pauseOnAction] = $input[fs][pauseOnAction]=='true'? true : false;
	$output[fs][pauseOnHover] = $input[fs][pauseOnHover]=='true'? true : false;
	$output[width] = is_numeric($input[width])? (int)$input[width] : $egs[width];
	$output[height] = is_numeric($input[height])? (int)$input[height] : $egs[height];
	$output[enlarge] = $input[enlarge]=='true'? true : false;
	$output[auto_insert] = is_numeric($input[auto_insert])? (int)$input[auto_insert] : $egs[auto_insert];
	$output[title] = $input[title]=='true'? true : false;
	$output[shortcode] = $input[shortcode]=='true'? true : false;
	$output[exclude] = $input[exclude]=='true'? true : false;
	return $output;
}
function easygalleryslider_options_page() {
	?>
	<div>
	<h2>Easy Gallery Slider</h2>
	<div id="egs-help" style="padding:4px 15px; width: 80%; background: #dedede; border-radius: 0 0 10px 10px;">
	<p>This slider generates slides per post from images that are attached in the usual Wordpress manner (gallery).  </p>
	<p><strong>How to use</strong><br />
	1. Choose a context for the <em>Automatically insert above</em> option.<br />
	2. Use the shortcode <em>[egslider]</em><br />
	<span style="margin-left:20px;text-size:90%;">The shortcode will not work on pages where the automatic slider is displayed.</span><br />
	</p>
	</div>
	<form action="options.php" method="post">
	<?php settings_fields('easygalleryslider_options'); ?>
	<?php do_settings_sections('easygalleryslider'); ?>
	<p />
	<input name="Submit" type="submit" value="<?php esc_attr_e('Save Changes'); ?>" />
	</form></div>
	
	<?php
}

//[egs] shortcode
function egs_shortcode( $atts=null ){
	return easygalleryslider_insert();
}

//Plugin init
function easygalleryslider_activator() {
	global $wpdb;
	if (function_exists('is_multisite') && is_multisite()) {
		// check if it is a network activation - if so, run the activation function for each blog id
		if (isset($_GET['networkwide']) && ($_GET['networkwide'] == 1)) {
	                $old_blog = $wpdb->blogid;
			// Get all blog ids
			$blogids = $wpdb->get_col($wpdb->prepare("SELECT blog_id FROM $wpdb->blogs"));
			foreach ($blogids as $blog_id) {
				switch_to_blog($blog_id);
				easygalleryslider_activate();
			}
			switch_to_blog($old_blog);
			return;
		}	
	}
	easygalleryslider_activate();
	chmod(WP_PLUGIN_DIR."/easy-gallery-slider/cache", 0775);
}
function easygalleryslider_activate() {
	$opt = get_option('easygalleryslider');
		$egs = array();
		$egs[fs][animation] = isset($opt[fs][animation])? $opt[fs][animation] : 'fade';
		$egs[fs][slideDirection] = isset($opt[fs][slideDirection])? $opt[fs][slideDirection] : 'horizontal';
		$egs[fs][slideshow] = isset($opt[fs][slideshow])? $opt[fs][slideshow] : true;
		$egs[fs][slideshowSpeed] = isset($opt[fs][slideshowSpeed])? $opt[fs][slideshowSpeed] : 5000;
		$egs[fs][animationDuration] = isset($opt[fs][animationDuration])? $opt[fs][animationDuration] : 600;
		$egs[fs][directionNav] = isset($opt[fs][directionNav])? $opt[fs][directionNav] : false;
		$egs[fs][controlNav] = isset($opt[fs][controlNav])? $opt[fs][controlNav] : true;
		$egs[fs][keyboardNav] = isset($opt[fs][keyboardNav])? $opt[fs][keyboardNav] : false;
		$egs[fs][mousewheel] = isset($opt[fs][mousewheel])? $opt[fs][mousewheel] : false;
		$egs[fs][pausePlay] = isset($opt[fs][pausePlay])? $opt[fs][pausePlay] : false;
		$egs[fs][randomize] = isset($opt[fs][randomize])? $opt[fs][randomize] : false;
		$egs[fs][animationLoop] = isset($opt[fs][animationLoop])? $opt[fs][animationLoop] : true;
		$egs[fs][pauseOnAction] = isset($opt[fs][pauseOnAction])? $opt[fs][pauseOnAction] : false;
		$egs[fs][pauseOnHover] = isset($opt[fs][pauseOnHover])? $opt[fs][pauseOnHover] : false;
		$egs[width] = isset($opt[width])? $opt[width] : 1200;
		$egs[height] = isset($opt[height])? $opt[height] : 300;
		$egs[enlarge] = isset($opt[enlarge])? $opt[enlarge] : true;
		$egs[auto_insert] = isset($opt[auto_insert])? $opt[auto_insert] : 0;
		$egs[title] = isset($opt[title])? $opt[title] : false;
		$egs[shortcode] = isset($opt[shortcode])? $opt[shortcode] : false;
		$egs[exclude] = isset($opt[exclude])? $opt[exclude] : false;
		update_option('easygalleryslider',$egs);
}
register_activation_hook( __FILE__, 'easygalleryslider_activator' );

?>
